# Local Human

This is an agent which takes input from the command line in the `act` function. It is used in the [interactive script](https://github.com/facebookresearch/ParlAI/blob/main/parlai/scripts/interactive.py).

## Basic Examples

Interact with a KVMemNN model trained on Persona-Chat.
```bash
python projects/personachat/scripts/kvmemnn_interactive.py
```
